@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { IotToLambdaProps, IotToLambda } = require('@aws-solutions-constructs/aws-iot-lambda');
 
 const props: IotToLambdaProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         code: lambda.Code.asset(`${__dirname}/lambda`),
         runtime: lambda.Runtime.NODEJS_10_X,
@@ -67,9 +66,8 @@ new IotToLambda(scope: Construct, id: string, props: IotToLambdaProps);
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new lambda function or use an existing lambda function|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user provided props to override the default props for lambda.Function|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |iotTopicRuleProps?|[`iot.CfnTopicRuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iot.CfnTopicRuleProps.html)|User provided CfnTopicRuleProps to override the defaults|
 
 ## Pattern Properties
@@ -91,6 +89,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ## Architecture
 
@@ -128,7 +127,6 @@ class IotToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -136,10 +134,9 @@ class IotToLambda(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         access:
         :access:: public
@@ -149,7 +146,6 @@ class IotToLambda(
         :summary:: Constructs a new instance of the IotToLambda class.
         """
         props = IotToLambdaProps(
-            deploy_lambda=deploy_lambda,
             iot_topic_rule_props=iot_topic_rule_props,
             existing_lambda_obj=existing_lambda_obj,
             lambda_function_props=lambda_function_props,
@@ -172,7 +168,6 @@ class IotToLambda(
     jsii_type="@aws-solutions-constructs/aws-iot-lambda.IotToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "iot_topic_rule_props": "iotTopicRuleProps",
         "existing_lambda_obj": "existingLambdaObj",
         "lambda_function_props": "lambdaFunctionProps",
@@ -182,30 +177,23 @@ class IotToLambdaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided props to override the default props. If ``deploy`` is set to true only then this property is required Default: - Default props are used
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
         summary:
         :summary:: The properties for the IotToLambda class.
         """
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(
-                **iot_topic_rule_props
-            )
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {
-            "deploy_lambda": deploy_lambda,
             "iot_topic_rule_props": iot_topic_rule_props,
         }
         if existing_lambda_obj is not None:
@@ -213,17 +201,6 @@ class IotToLambdaProps:
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new lambda function or use an existing lambda function.
-
-        If set to false, you must provide a lambda function object as ``existingObj``
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
         """User provided CfnTopicRuleProps to override the defaults.
@@ -235,9 +212,7 @@ class IotToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -248,9 +223,7 @@ class IotToLambdaProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided props to override the default props.
-
-        If ``deploy`` is set to true only then this property is required
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default props are used
